@@ -367,7 +367,7 @@ class Query:
             else:
                 # otherwise, check if internal and original data types are not consistent each other
                 consistent_vec = consistent_datatypes[field.internalDataType.lower()]
-                if field.internalDataType.lower() == "numeric" and field.sourceDataType.lower() not in consistent_vec:
+                if (field.internalDataType.lower() == "numeric" or field.internalDataType.lower() == "string") and field.sourceDataType.lower() not in consistent_vec:
                     # if internal and original data types are not consistent each other use this pattern
                     # aggregation column (original data type, to internal data type ) AS Alias
                     if field.alias is None:
